==> eam-wshub-proxyclient-11.5-4-sources.jar: net/datastream/schemas/mp_fields/COMMENT_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour COMMENT_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="COMMENT_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYCOMMENTID"/>
 *         &lt;element name="COMMENTTEXT" type="{http://schemas.datastream.net/MP_fields}CODE32700_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRINT"/>
 *         &lt;element name="CREATEDDATE" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *         &lt;element name="UPDATEDDATE" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *         &lt;element name="CREATEDBY" type="{http://schemas.datastream.net/MP_fields}USERID_Type" minOccurs="0"/>
 *         &lt;element name="UPDATEDBY" type="{http://schemas.datastream.net/MP_fields}USERID_Type" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSLATEDTEXT" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="is_html_comment" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "COMMENT_Type", propOrder = {
    "entitycommentid",
    "commenttext",
    "print",
    "createddate",
    "updateddate",
    "createdby",
    "updatedby",
    "categoryid",
    "organizationid",
    "translatedtext"
})
@XmlSeeAlso({
    COMMENTAUDITITEM_Type.class
})
public class COMMENT_Type {

    @XmlElement(name = "ENTITYCOMMENTID", required = true)
    protected ENTITYCOMMENTID_Type entitycommentid;
    @XmlElement(name = "COMMENTTEXT", required = true)
    protected String commenttext;
    @XmlElement(name = "PRINT", required = true)
    protected String print;
    @XmlElement(name = "CREATEDDATE")
    protected DATETIME createddate;
    @XmlElement(name = "UPDATEDDATE")
    protected DATETIME updateddate;
    @XmlElement(name = "CREATEDBY")
    protected USERID_Type createdby;
    @XmlElement(name = "UPDATEDBY")
    protected USERID_Type updatedby;
    @XmlElement(name = "CATEGORYID")
    protected CATEGORYID categoryid;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "TRANSLATEDTEXT")
    protected String translatedtext;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "is_html_comment")
    protected String is_Html_Comment;

    /**
     * Obtient la valeur de la propriété entitycommentid.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYCOMMENTID_Type }
     *     
     */
    public ENTITYCOMMENTID_Type getENTITYCOMMENTID() {
        return entitycommentid;
    }

    /**
     * Définit la valeur de la propriété entitycommentid.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYCOMMENTID_Type }
     *     
     */
    public void setENTITYCOMMENTID(ENTITYCOMMENTID_Type value) {
        this.entitycommentid = value;
    }

    /**
     * Obtient la valeur de la propriété commenttext.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOMMENTTEXT() {
        return commenttext;
    }

    /**
     * Définit la valeur de la propriété commenttext.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOMMENTTEXT(String value) {
        this.commenttext = value;
    }

    /**
     * Obtient la valeur de la propriété print.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRINT() {
        return print;
    }

    /**
     * Définit la valeur de la propriété print.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRINT(String value) {
        this.print = value;
    }

    /**
     * Obtient la valeur de la propriété createddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Définit la valeur de la propriété createddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Obtient la valeur de la propriété updateddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUPDATEDDATE() {
        return updateddate;
    }

    /**
     * Définit la valeur de la propriété updateddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUPDATEDDATE(DATETIME value) {
        this.updateddate = value;
    }

    /**
     * Obtient la valeur de la propriété createdby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Définit la valeur de la propriété createdby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Obtient la valeur de la propriété updatedby.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUPDATEDBY() {
        return updatedby;
    }

    /**
     * Définit la valeur de la propriété updatedby.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUPDATEDBY(USERID_Type value) {
        this.updatedby = value;
    }

    /**
     * Obtient la valeur de la propriété categoryid.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Définit la valeur de la propriété categoryid.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété translatedtext.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRANSLATEDTEXT() {
        return translatedtext;
    }

    /**
     * Définit la valeur de la propriété translatedtext.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRANSLATEDTEXT(String value) {
        this.translatedtext = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Obtient la valeur de la propriété is_Html_Comment.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Html_Comment() {
        return is_Html_Comment;
    }

    /**
     * Définit la valeur de la propriété is_Html_Comment.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Html_Comment(String value) {
        this.is_Html_Comment = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/COMMENT_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for COMMENT_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="COMMENT_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTITYCOMMENTID"/>
 *         &lt;element name="COMMENTTEXT" type="{http://schemas.datastream.net/MP_fields}CODE32700_Type"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRINT"/>
 *         &lt;element name="CREATEDDATE" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *         &lt;element name="UPDATEDDATE" type="{http://www.openapplications.org/oagis_segments}DATETIME" minOccurs="0"/>
 *         &lt;element name="CREATEDBY" type="{http://schemas.datastream.net/MP_fields}USERID_Type" minOccurs="0"/>
 *         &lt;element name="UPDATEDBY" type="{http://schemas.datastream.net/MP_fields}USERID_Type" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSLATEDTEXT" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="is_html_comment" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "COMMENT_Type", propOrder = {
    "entitycommentid",
    "commenttext",
    "print",
    "createddate",
    "updateddate",
    "createdby",
    "updatedby",
    "categoryid",
    "organizationid",
    "translatedtext"
})
@XmlSeeAlso({
    COMMENTAUDITITEM_Type.class
})
public class COMMENT_Type {

    @XmlElement(name = "ENTITYCOMMENTID", required = true)
    protected ENTITYCOMMENTID_Type entitycommentid;
    @XmlElement(name = "COMMENTTEXT", required = true)
    protected String commenttext;
    @XmlElement(name = "PRINT", required = true)
    protected String print;
    @XmlElement(name = "CREATEDDATE")
    protected DATETIME createddate;
    @XmlElement(name = "UPDATEDDATE")
    protected DATETIME updateddate;
    @XmlElement(name = "CREATEDBY")
    protected USERID_Type createdby;
    @XmlElement(name = "UPDATEDBY")
    protected USERID_Type updatedby;
    @XmlElement(name = "CATEGORYID")
    protected CATEGORYID categoryid;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "TRANSLATEDTEXT")
    protected String translatedtext;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "is_html_comment")
    protected String is_Html_Comment;

    /**
     * Gets the value of the entitycommentid property.
     * 
     * @return
     *     possible object is
     *     {@link ENTITYCOMMENTID_Type }
     *     
     */
    public ENTITYCOMMENTID_Type getENTITYCOMMENTID() {
        return entitycommentid;
    }

    /**
     * Sets the value of the entitycommentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ENTITYCOMMENTID_Type }
     *     
     */
    public void setENTITYCOMMENTID(ENTITYCOMMENTID_Type value) {
        this.entitycommentid = value;
    }

    /**
     * Gets the value of the commenttext property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCOMMENTTEXT() {
        return commenttext;
    }

    /**
     * Sets the value of the commenttext property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCOMMENTTEXT(String value) {
        this.commenttext = value;
    }

    /**
     * Gets the value of the print property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPRINT() {
        return print;
    }

    /**
     * Sets the value of the print property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPRINT(String value) {
        this.print = value;
    }

    /**
     * Gets the value of the createddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCREATEDDATE() {
        return createddate;
    }

    /**
     * Sets the value of the createddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCREATEDDATE(DATETIME value) {
        this.createddate = value;
    }

    /**
     * Gets the value of the updateddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getUPDATEDDATE() {
        return updateddate;
    }

    /**
     * Sets the value of the updateddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setUPDATEDDATE(DATETIME value) {
        this.updateddate = value;
    }

    /**
     * Gets the value of the createdby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getCREATEDBY() {
        return createdby;
    }

    /**
     * Sets the value of the createdby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setCREATEDBY(USERID_Type value) {
        this.createdby = value;
    }

    /**
     * Gets the value of the updatedby property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUPDATEDBY() {
        return updatedby;
    }

    /**
     * Sets the value of the updatedby property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUPDATEDBY(USERID_Type value) {
        this.updatedby = value;
    }

    /**
     * Gets the value of the categoryid property.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Sets the value of the categoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the translatedtext property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTRANSLATEDTEXT() {
        return translatedtext;
    }

    /**
     * Sets the value of the translatedtext property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTRANSLATEDTEXT(String value) {
        this.translatedtext = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Gets the value of the is_Html_Comment property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Html_Comment() {
        return is_Html_Comment;
    }

    /**
     * Sets the value of the is_Html_Comment property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Html_Comment(String value) {
        this.is_Html_Comment = value;
    }

}
